johnny - generic dep(p)endencies tracker
========================================

Tracking versions and alerting stale dependencies. Johnny is tool and language
independent and doesn't need central service.

Currently supports: git, gitlab (gitlab.com and self-hosted), github, arch and aur

Running
-------

```bash
pip install johnny
johnny examples/deps.toml
```
